==> boilerplate-bootstrap-0.2.1.tgz: package/tasks/replacements.js <==
/*
 * Regex for converting Bootstrap's liquid
 * templates over to Handlebars.
 * Copyright (c) 2013 Jon Schlinkert
 * Licensed under the MIT license.
 */

exports.init = function(grunt) {

  var rules = {
    one: /({%)\s+(if|unless|elsif)\s*(.*)\s*(.*)\s+/,
    two: /((and|or|not|contains|(!=|==|<=|>=|<|>)\s+))\s*"(\S*)"([\s*]%})/,
    commentStart: {
      name: 'comment.block.begin.liquid',
      pattern: /({%\s*comment\s*%})/,
      replacement: '{{!--'
    },
    commentEnd: {
      name: 'comment.block.end.liquid',
      pattern: /({%s*endcomments*%})/,
      replacement: ' --}}'
    }
  };

  exports.regex = {
    patterns: [
      // Layouts
      // -------------------------------------------------
      {
        // Replace {{content}} tag with {{> body }} partial
        pattern: /(?:\{\{\s*content\s*\}\})/g,
        replacement: '{{> body }}'
      },
      {
        // Append `.html` ext to layouts defined in YFM
        pattern: /(---\s*layout:.*)/g,
        replacement: '$1.hbs'
      },

      // Comments
      {
        name: 'comment.block.liquid',
        pattern: /({% comment %}[\s*]?)(.*[\s*]?.*)([\s*]?{% endcomment %})/,
        replacement: '{{!-- $2 --}}'
      },


      // Logic statements
      // -------------------------------------------------
      {
        name: 'tag.logical.liquid',
        // {% if page.title == "Bootstrap" %}
        // pattern: /({%)\s+(if|unless|elsif)\s*(.*)\s*(.*)\s+((and|or|not|contains|(!=|==|<=|>=|<|>)\s+))\s*"(\S*)"([\s*]%})/g,
        pattern: new RegExp("(" + rules.one.source + rules.two.source + ")"),
        replacement: '{{#is $4 "$9"}}'
      },
      {
        name: 'tag.logical.else.liquid',
        pattern: /(\{% else if %\})/,
        replacement: '{{else}}'
      },
      {
        name: 'tag.logical.endif.liquid',
        pattern: /(\{% endif %\})/,
        replacement: '{{/is}}'
      },
      // {
      //   pattern: /(\{% else if %\})\s*(\{\{.*)\s*(\{% endif %\})/g,
      //   replacement: '{{#isnt title "Bootstrap"}}\n    $2\n  {{/isnt}}'
      // },

      // Navigation
      // -------------------------------------------------
      {
        // Replace liquid tags in nav anchors with Handlebars helpers.
        //
        // Example:
        //    From: {% if page.slug == "getting-started" %} class="active"{% endif %}
        //    To:   {{#is basename "getting-started"}} class="active"{{/is}}
        //
        pattern: /(\{%\s*if|elsif)\s(page\.slug[ ]?==[ ]?)(".*)[ ]%\}(.*)(?:\{% endif %\})/g,
        replacement: '{{#is slug $3}}$4{{/is}}'
      },

      {
        // Replace liquid {% if/elseif %} navigation blocks with Handlebars {{#is/unless}}
        pattern: /(\{%\s*)\b(.*)\b\s(\b(.*)\b\.(.*)\s==\s)(.*\s*)(%\})(\s.*)(\s*)(\{(%|\{)\s*\b(.*)\b)\s(.*)(?:\.html)(\s*%\})/g,
        replacement: '{{#is slug $6}} $9 {{> $13 }}\n              {{/is}}'
      },
      {
        // Clean up any remaining {% endif %}'s
        pattern: /(?:\{%\s*endif\s*%\})/g,
        replacement: '\n'
      },

      // Tags
      // -------------------------------------------------
      {
        // Replace liquid includes with Handlebars partials
        pattern: /(\{%\s*include\s*)(|(?:.*)+)(?:\.html\s*%\})/g,
        replacement: '{{> $2 }}'
      },
      {
        // Strip 'page' path from tag variables
        pattern: /(\{\{\s*page\.)(.*)(?:\}\})/g,
        replacement: '{{ $2}}'
      },
      {
        // Remove leftover "page" variables
        pattern: /\b(is )(?:page\.)\b/g,
        replacement: '$1'
      },
      {
        // Replace "{{ base_url }}/dist" and "{{ base_url }}/assets" with "{{ assets }}"
        pattern: /(?:\{\{\s*base_url\s*\}\}(assets|dist))/g,
        replacement: '{{ assets }}'
      },
      // Use {{root}} variable once it's implemented in Assemble
      // {
      //   // Replace "{{ base_url }}/dist" and "{{ base_url }}/assets" with "{{ assets }}"
      //   pattern: /(href=")(\{\{[ ]?base_url[ ]?\}\})[\/]?(|.*)[ ]?"/g,
      //   replacement: 'href="{{root}}/$3.html\"'
      // },
      // {
      //   // cleanup from previous regex
      //   pattern: /({{root}}\/.html)/g,
      //   replacement: '{{root}}\/'
      // },

      {
        // Replace "{{ base_url }}/dist" and "{{ base_url }}/assets" with "{{ assets }}"
        pattern: /(\{\{ base_url \}\}2\.3\.2)/g,
        replacement: 'http://getbootstrap.com/2.3.2'
      },
      {
        // Replace "{{ base_url }}/dist" and "{{ base_url }}/assets" with "{{ assets }}"
        pattern: /(href=")(\{\{[ ]?base_url[ ]?\}\})[\/]?(|.*)[ ]?"/g,
        replacement: 'href="./$3.html\"'
      },
      {
        // cleanup from previous regex
        pattern: /.\/.html/g,
        replacement: 'index.html'
      },
      {
        // Replace liquid filter with {{now}} helper
        pattern: /site\.time \| date\:/g,
        replacement: 'now'
      },

      // Code blocks and syntax highlighting
      // -------------------------------------------------
      {
        // highlight.js doesn't support line numbers, so convert the
        // language definition to just "html"
        pattern: /html linenos/g,
        replacement: 'html'
      },
      {
        // Identify the language definitions after the first code
        // fence (```) for each highlighted code block.
        pattern: /(\{%\s*)\s*(?:highlight)\s*(bash|js|html|css|less)\s*(%\})/g,
        replacement: '\n{{#markdown}}\n```$2'
      },
      {
        pattern: /(\{%\s*endhighlight\s*%\})/g,
        replacement: '```\n{{/markdown}}\n'
      },

      // Add script and link tags for highlight.js
      // -------------------------------------------------
      {
        // Find the holder.js script tag, then just add it back
        // with highlight.js directly afterwards
        pattern: /(<script.*holder.js"><\/script>)/g,
        replacement: '$1\n<script src="{{ assets }}\/js/highlight.js"><\/script>' +
                     '\n<script>hljs.initHighlightingOnLoad();<\/script>'
      },
      {
        // replace Jekyll's 'pygments-manni.css' with 'github.css' for highlight.js,
        // and override the background color on github.css so it won't conflict
        // with Bootstrap's styles.
        pattern: /(pygments-manni)(.*">)/,
        replacement: 'github$2\n<style>pre code { background: transparent; }<\/style>'
      }
    ],
    comments: [
      {
        description: 'HTML comments',
        pattern: /(\<![\-\-\s\w\>\/]*\>)/g
      },
      {
        description: 'javascript comments',
        pattern: /(\/\*[\w\'\s\r\n\*]*\*\/)|(\/\/[\w\s\']*)/g
      },
      {
        description: 'HTML or javascript comments',
        pattern: /(\/\*[\w\'\s\r\n\*]*\*\/)|(\/\/[\w\s\']*)|(\<![\-\-\s\w\>\/]*\>)/g
      },
      {
        description: 'JavaScript: block and line comments',
        pattern: /(\/\*([^*]|[\r\n]|(\*+([^*\/]|[\r\n])))*\*+\/)|(\/\/.*)/g
      },
      {
        description: 'JavaScript: banner block comments',
        pattern: /([^\/"']+|"(?:[^"\\]|\\.)*"|'(?:[^'\\]|\\.)*')|\/\*(?:[^*]|\*+[^*\/])*\*+\/|\/\/.*/
      },

    ],
    // liquid: [
    //   {
    //     name: 'tag.name',
    //     pattern: /(?:{%[\s]?)\s*(\w+)/,
    //     replacement: ''
    //   },
    //   {
    //     name: "variable.begin.liquid",
    //     pattern: /{{/
    //   },
    //   {
    //     name: "variable.end.liquid",
    //     pattern: /}}/
    //   },
    //   {
    //     name: "variable.end.incomplete.liquid",
    //     pattern: /}}?/
    //   },
    //   {
    //     name: 'tag.begin.liquid',
    //     pattern: /\{\%/,
    //     replacement: ''
    //   },
    //   {
    //     name: 'tag.end.liquid',
    //     pattern: /\%\}/,
    //     replacement: ''
    //   },
    //   {
    //     name: 'keyword.operator.logical.liquid',
    //     pattern: /(\s+(and|or|not|contains|(\!\=|\=\=|<\=|>\=|<|>))\s+)/,
    //     replacement: '$2'
    //   },
    //   {
    //     name: "template.tag.name.liquid",
    //     pattern: /(?:{%)\s*(\w+)/,
    //     replacement: '$1'
    //   },
    //   {
    //     name: "filter.separator.liquid",
    //     pattern: /\|/
    //   },
    //   {
    //     name: "argument.separator.liquid",
    //     pattern: /,/
    //   },
    //   {
    //     name: "filter.argument.separator.liquid",
    //     pattern: /\:/
    //   },
    //   {
    //     name: "variable.argument.attribute.separator.liquid",
    //     pattern: /\./
    //   },
    //   {
    //     name: "variable.signature",
    //     pattern: /\(?[\w\-\.\[\]]\)?/
    //   },
    //   {
    //     name: "variable.segment",
    //     pattern: /[\w\-]/
    //   },
    //   {
    //     name: "quoted.string",
    //     pattern: /"[^"]*"|'[^']*'/
    //   },
    //   {
    //     name: "quoted.fragment",
    //     pattern: /"[^"]*"|'[^']*'|(?:[^\s,\\]|"[^"]*"|'[^']*')+/
    //   },
    //   {
    //     name: "strict.quote.fragment",
    //     pattern: /"[^"]+"|'[^']+'|[^\s|:,]+/ // "[^"]+"|'[^']+'|[^\s]+
    //   },
    //   {
    //     name: "first.filter.argument.liquid",
    //     pattern: /\:(?:"[^"]+"|'[^']+'|[^\s|:,]+)/
    //   },
    //   {
    //     name: "other.filter.argument.liquid",
    //     pattern: /,(?:"[^"]+"|'[^']+'|[^\s|:,]+)/
    //   },
    //   {
    //     name: "spaceless.filter.liquid",
    //     pattern: /^(?:'[^']+'|"[^"]+"|[^'"])*\|(?:"[^"]+"|'[^']+'|[^\s|:,]+)(?::(?:"[^"]+"|'[^']+'|[^\s|:,]+(?:,(?:"[^"]+"|'[^']+'|[^\s|:,]+)*)?))/
    //   },
    //   {
    //     name: "expression.liquid",
    //     pattern: /(?:"[^"]*"|'[^']*'|(?:[^\\s,\\|'"]|"[^"]*"|'[^']*')+(?:^(?:'[^']+'|"[^"]+"|[^'"])*\|(?:"[^"]+"|'[^']+'|[^\s|:,]+)(?::(?:"[^"]+"|'[^']+'|[^\s|:,]+(?:,(?:"[^"]+"|'[^']+'|[^\s|:,]+)*)?)*)))/
    //   },
    //   {
    //     name: "tag.attributes.liquid",
    //     pattern: /(?:{[%|\{]?.*)(?:\w+)\s*:\s*("[^"]*"|'[^']*'|(?:[^\s,\|'"]|"[^"]*"|'[^']*')+)(?:.*[%|\}]?})/
    //   },
    //   {
    //     name: "any.starting.tag.liquid",
    //     pattern: /\{\{|\{\%/
    //   },
    //   {
    //     name: "template.partial.parser.liquid",
    //     pattern: /(\{%.*?%\}|\{\{.*?\}\}?)/
    //   },
    //   {
    //     name: "template.parser.liquid",
    //     pattern: /(\{%.*?%\}|\{\{.*?\}\}?)|(\{\{|\{%)/
    //   },
    //   {
    //     name: "variable.parser.liquid",
    //     pattern: /\\[[^\\]]+\\]|[\w-]+\\??/
    //   },
    //   {
    //     pattern: /(\s*(false|true|nil)\s*)/,
    //     name: "constant.language.liquid"
    //   }
    // ],
    // generic: [
    //   {
    //     matches: {
    //       1: {
    //         name: 'keyword.operator',
    //         pattern: /\=/g
    //       },
    //       2: {
    //         name: 'string',
    //         matches: {
    //           name: 'constant.character.escape',
    //           pattern: /\\('|"){1}/g
    //         }
    //       }
    //     },
    //     pattern: /(\(|\s|\[|\=|:)(('|")([^\\\1]|\\.)*?(\3))/gm
    //   },
    //   {
    //     name: 'comment',
    //     pattern: /\/\*[\s\S]*?\*\/|(\/\/|\#)[\s\S]*?$/gm
    //   },
    //   {
    //     name: 'constant.numeric',
    //     pattern: /\b(\d+(\.\d+)?(e(\+|\-)?\d+)?(f|d)?|0x[\da-f]+)\b/gi
    //   },
    //   {
    //     matches: {
    //       1: 'keyword'
    //     },
    //     pattern: /\b(and|array|as|bool(ean)?|c(atch|har|lass|onst)|d(ef|elete|o(uble)?)|e(cho|lse(if)?|xit|xtends|xcept)|f(inally|loat|or(each)?|unction)|global|if|import|int(eger)?|long|new|object|or|pr(int|ivate|otected)|public|return|self|st(ring|ruct|atic)|switch|th(en|is|row)|try|(un)?signed|var|void|while)(?=\(|\b)/gi
    //   },
    //   {
    //     name: 'constant.language',
    //     pattern: /true|false|null/g
    //   },
    //   {
    //     name: 'keyword.operator',
    //     pattern: /\+|\!|\-|&(gt|lt|amp);|\||\*|\=/g
    //   },
    //   {
    //     matches: {
    //       1: 'function.call'
    //     },
    //     pattern: /(\w+?)(?=\()/g
    //   },
    //   {
    //     matches: {
    //       1: 'storage.function',
    //       2: 'entity.name.function'
    //     },
    //     pattern: /(function)\s(.*?)(?=\()/g
    //   }
    // ],
    // html: [
    //   {
    //     name: 'source.css.embedded',
    //     pattern: /<style(.*?)>([\s\S]*?)<\/style>/gm
    //   },
    //   {
    //     name: 'source.js.inline',
    //     pattern: /<script(!? src="){{([\s\S]*?)}}([\s\S]*?)"><\/script>/g,
    //     replacement: ''
    //   },
    //   {
    //     name: 'source.js.embedded',
    //     pattern: /<script(?! src)(.*?)>([\s\S]*?)<\/script>/gm,
    //     replacement: ''
    //   },
    //   {
    //     name: 'comment.html',
    //     pattern: /<\!--[\S\s]*?-->/g
    //   },
    //   {
    //     pattern: /(<)|(\/?\??>)/g,
    //     matches: {
    //       1: 'support.tag.open',
    //       2: 'support.tag.close'
    //     }
    //   },
    //   {
    //     name: 'support.tag',
    //     pattern: /(<\??)(\/|\!?)(\w+)/g,
    //     matches: {
    //       1: 'support.tag',
    //       2: 'support.tag.special',
    //       3: 'support.tagname'
    //     }
    //   },
    //   {
    //     name: 'support.attribute',
    //     pattern: /([a-z-]+)(?=\=)/gi
    //   },
    //   {
    //     name: 'support.value',
    //     pattern: /(=)('|")(.*?)(\2)/g,
    //     matches: {
    //       1: 'support.operator',
    //       2: 'string.quote',
    //       3: 'string.value',
    //       4: 'string.quote'
    //     }
    //   },
    //   {
    //     name: '',
    //     pattern: /(=)([a-zA-Z\-0-9]*)\b/g,
    //     matches: {
    //       1: 'support.operator',
    //       2: 'support.value'
    //     }
    //   },
    //   {
    //     name: '',
    //     pattern: /\s(\w+)(?=\s|>)(?![\s\S]*<)/g,
    //     matches: {
    //       1: 'support.attribute'
    //     }
    //   }
    // ],
    // javascript: [
    //   /* matches $. or $( */
    //   {
    //     name: 'selector',
    //     pattern: /(\s|^)\$(?=\.|\()/g
    //   },
    //   {
    //     name: 'support',
    //     pattern: /\b(window|document)\b/g
    //   },
    //   {
    //     matches: {1: 'support.property'},
    //     pattern: /\.(length|node(Name|Value))\b/g
    //   },
    //   {
    //     matches: {1: 'support.function'},
    //     pattern: /(setTimeout|setInterval)(?=\()/g

    //   },
    //   {
    //     matches: {1: 'support.method'},
    //     pattern: /\.(getAttribute|push|getElementById|getElementsByClassName|log|setTimeout|setInterval)(?=\()/g
    //   },
    //   {
    //     matches: {
    //       1: 'support.tag.script',
    //       2: [
    //         {
    //           name: 'string',
    //           pattern: /('|")(.*?)(\1)/g
    //         },
    //         {
    //           name: 'entity.tag.script',
    //           pattern: /(\w+)/g
    //         }
    //       ],
    //       3: 'support.tag.script'
    //     },
    //     pattern: /(&lt;\/?)(script.*?)(&gt;)/g
    //   },

    //   /**
    //    * matches any escaped characters inside of a js regex pattern
    //    */
    //   {
    //     name: 'string.regexp',
    //     matches: {
    //       1: 'string.regexp.open',
    //       2: {
    //         name: 'constant.regexp.escape',
    //         pattern: /\\(.){1}/g
    //       },
    //       3: 'string.regexp.close',
    //       4: 'string.regexp.modifier'
    //     },
    //     pattern: /(\/)(?!\*)(.+)(\/)([igm]{0,3})/g
    //   },

    //   /**
    //    * matches runtime function declarations
    //    */
    //   {
    //     matches: {
    //       1: 'storage',
    //       3: 'entity.function'
    //     },
    //     pattern: /(var)?(\s|^)(.*)(?=\s?=\s?function\()/g
    //   },

    //   /**
    //    * matches constructor call
    //    */
    //   {
    //     matches: {
    //       1: 'keyword',
    //       2: 'entity.function'
    //     },
    //     pattern: /(new)\s+(.*)(?=\()/g
    //   },

    //   /**
    //    * matches any function call in the style functionName: function()
    //    */
    //   {
    //     name: 'entity.function',
    //     pattern: /(\w+)(?=:\s{0,}function)/g
    //   }
    // ],
    // css: [
    //   {
    //     name: 'comment',
    //     pattern: /\/\*[\s\S]*?\*\//gm
    //   },
    //   {
    //     name: 'constant.hex-color',
    //     pattern: /#([a-f0-9]{3}|[a-f0-9]{6})(?=;|\s)/gi
    //   },
    //   {
    //     matches: {
    //       1: 'constant.numeric',
    //       2: 'keyword.unit'
    //     },
    //     pattern: /(\d+)(px|em|cm|s|%)?/g
    //   },
    //   {
    //     name: 'string',
    //     pattern: /('|")(.*?)\1/g
    //   },
    //   {
    //     name: 'support.css-property',
    //     matches: {
    //       1: 'support.vendor-prefix'
    //     },
    //     pattern: /(-o-|-moz-|-webkit-|-ms-)?[\w-]+(?=\s?:)(?!.*\{)/g
    //   },
    //   {
    //     matches: {
    //       1: [
    //         {
    //           name: 'entity.name.sass',
    //           pattern: /&amp;/g
    //         },
    //         {
    //           name: 'direct-descendant',
    //           pattern: /&gt;/g
    //         },
    //         {
    //           name: 'entity.name.class',
    //           pattern: /\.[\w\-_]+/g
    //         },
    //         {
    //           name: 'entity.name.id',
    //           pattern: /\#[\w\-_]+/g
    //         },
    //         {
    //           name: 'entity.name.pseudo',
    //           pattern: /:[\w\-_]+/g
    //         },
    //         {
    //           name: 'entity.name.tag',
    //           pattern: /\w+/g
    //         }
    //       ]
    //     },
    //     pattern: /([\w\ ,:\.\#\&\;\-_]+)(?=.*\{)/g
    //   },
    //   {
    //     matches: {
    //       2: 'support.vendor-prefix',
    //       3: 'support.css-value'
    //     },
    //     pattern: /(:|,)\s?(-o-|-moz-|-webkit-|-ms-)?([a-zA-Z-]*)(?=\b)(?!.*\{)/g
    //   },
    //   {
    //     matches: {
    //       1: 'support.tag.style',
    //       2: [
    //         {
    //           name: 'string',
    //           pattern: /('|")(.*?)(\1)/g
    //         },
    //         {
    //           name: 'entity.tag.style',
    //           pattern: /(\w+)/g
    //         }
    //       ],
    //       3: 'support.tag.style'
    //     },
    //     pattern: /(&lt;\/?)(style.*?)(&gt;)/g
    //   }
    // ]
  };
  return exports;
};

==> boilerplate-bootstrap-0.2.2.tgz: package/tasks/replacements.js <==
/*
 * Regex for converting Bootstrap's liquid
 * templates over to Handlebars.
 * Copyright (c) 2013 Jon Schlinkert
 * Licensed under the MIT license.
 */

exports.init = function(grunt) {

  exports.regex = {
    patterns: [
      // Layouts
      // -------------------------------------------------
      {
        // Replace {{content}} tag with {{> body }} partial
        pattern: /(?:\{\{\s*content\s*\}\})/g,
        replacement: '{{> body }}'
      },
      {
        // Append `.html` ext to layouts defined in YFM
        pattern: /(---\s*layout:.*)/g,
        replacement: '$1.hbs'
      },


      // Titles and basic variables
      // -------------------------------------------------
      {
        pattern: /(\{%\s*)(if\s(page\..+)\s==\s(.+))\s(%\})\s*(.+)(\{\{.*\}\}.*)/g,
        replacement: '{{#is $3 $4}}\n    $7\n  {{/is}}'
      },
      {
        pattern: /(\{% else if %\})\s*(\{\{.*)\s*(\{% endif %\})/g,
        replacement: '{{#isnt title "Bootstrap"}}\n    $2\n  {{/isnt}}'
      },

      // Navigation
      // -------------------------------------------------
      {
        // Replace liquid tags in nav anchors with Handlebars helpers.
        //
        // Example:
        //    From: {% if page.slug == "getting-started" %} class="active"{% endif %}
        //    To:   {{#is basename "getting-started"}} class="active"{{/is}}
        //
        pattern: /(\{%\s*if|elsif)\s(page\.slug[ ]?==[ ]?)(".*)[ ]%\}(.*)(?:\{% endif %\})/g,
        replacement: '{{#is slug $3}}$4{{/is}}'
      },
      {
        // Replace liquid {% if/elseif %} navigation blocks with Handlebars {{#is/unless}}
        pattern: /(\{%\s*)\b(.*)\b\s(\b(.*)\b\.(.*)\s==\s)(.*\s*)(%\})(\s.*)(\s*)(\{(%|\{)\s*\b(.*)\b)\s(.*)(?:\.html)(\s*%\})/g,
        replacement: '{{#is slug $6}} $9 {{> $13 }}\n              {{/is}}'
      },
      {
        // Clean up any remaining {% endif %}'s
        pattern: /(?:\{%\s*endif\s*%\})/g,
        replacement: '\n'
      },

      // Tags
      // -------------------------------------------------
      {
        // Replace liquid includes with Handlebars partials
        pattern: /(\{%\s*include\s*)(|(?:.*)+)(?:\.html\s*%\})/g,
        replacement: '{{> $2 }}'
      },
      {
        // Strip 'page' path from tag variables
        pattern: /(\{\{\s*page\.)(.*)(?:\}\})/g,
        replacement: '{{ $2}}'
      },
      {
        // Remove leftover "page" variables
        pattern: /\b(is )(?:page\.)\b/g,
        replacement: '$1'
      },
      {
        // Replace "{{ base_url }}/dist" and "{{ base_url }}/assets" with "{{ assets }}"
        pattern: /(?:\{\{\s*base_url\s*\}\}(assets|dist))/g,
        replacement: '{{ assets }}'
      },
      // Use {{root}} variable once it's implemented in Assemble
      // {
      //   // Replace "{{ base_url }}/dist" and "{{ base_url }}/assets" with "{{ assets }}"
      //   pattern: /(href=")(\{\{[ ]?base_url[ ]?\}\})[\/]?(|.*)[ ]?"/g,
      //   replacement: 'href="{{root}}/$3.html\"'
      // },
      // {
      //   // cleanup from previous regex
      //   pattern: /({{root}}\/.html)/g,
      //   replacement: '{{root}}\/'
      // },

      {
        // Replace "{{ base_url }}/dist" and "{{ base_url }}/assets" with "{{ assets }}"
        pattern: /(\{\{ base_url \}\}2\.3\.2)/g,
        replacement: 'http://getbootstrap.com/2.3.2'
      },
      {
        // Replace "{{ base_url }}/dist" and "{{ base_url }}/assets" with "{{ assets }}"
        pattern: /(href=")(\{\{[ ]?base_url[ ]?\}\})[\/]?(|.*)[ ]?"/g,
        replacement: 'href="./$3.html\"'
      },
      {
        // cleanup from previous regex
        pattern: /.\/.html/g,
        replacement: 'index.html'
      },
      {
        // Replace liquid filter with {{now}} helper
        pattern: /site\.time \| date\:/g,
        replacement: 'now'
      },

      // Code blocks and syntax highlighting
      // -------------------------------------------------
      {
        // highlight.js doesn't support line numbers, so convert the
        // language definition to just "html"
        pattern: /html linenos/g,
        replacement: 'html'
      },
      {
        // Identify the language definitions after the first code
        // fence (```) for each highlighted code block.
        pattern: /(\{%\s*)\s*(?:highlight)\s*(bash|js|html|css|less)\s*(%\})/g,
        replacement: '\n{{#markdown}}\n```$2'
      },
      {
        pattern: /(\{%\s*endhighlight\s*%\})/g,
        replacement: '```\n{{/markdown}}\n'
      },

      // Add script and link tags for highlight.js
      // -------------------------------------------------
      {
        pattern: /(\<meta name=\"description\" content=\"\"\>)/g,
        replacement: '<meta name="description" content="{{pkg.description}}">'
      },
      {
        // Find the holder.js script tag, then just add it back
        // with highlight.js directly afterwards
        pattern: /(<script.*holder.js"><\/script>)/g,
        replacement: '$1\n<script src="{{ assets }}\/js/highlight.js"><\/script>' +
                     '\n<script>hljs.initHighlightingOnLoad();<\/script>'
      },
      {
        // replace Jekyll's 'pygments-manni.css' with 'github.css' for highlight.js,
        // and override the background color on github.css so it won't conflict
        // with Bootstrap's styles.
        pattern: /(pygments-manni)(.*">)/,
        replacement: 'github$2\n<style>pre code { background: transparent; }<\/style>'
      }
    ]
  };

  return exports;
};
